/********************************************************************************************/
/********************              Master program to create            **********************/
/********************               the UVindex Database               **********************/
/********************   providing Import & Export Unit Value Indices   *********************/
*********************            from BACI, CEPII database 			   ********************/
/******************************************************************************************/

* 
					PROGRAM DEVELOPPED BY GAULIER, MARTIN, MEJEAN and ZIGNAGO
If you use it please cite the associated reference document:
International Trade Price Indices, Gaulier, Mjean, Martin, Zignago(2008) CEPII Working Paper.
;


******************
** adaptation pour projet indices par hs6 pour deflater
**  2 avril 2012
******************;


goptions devmap=winansi keymap=winansi;
options pagesize=100 linesize=100;

/*** paths  ***/

*db is the path where your source database is located;
libname db "E:\DATA_CE\trade_price";
*pr is the place you want to save your output;
libname pr "E:\DATA_CE\trade_price"; *for example;
*path to reach your sas programs ;
%let cheminF=O:\BACI\TradePrices\progs; 


*** importation des donnes;

data db.exp;
	infile "E:\DATA_CE\trade_price\exptp92_08.csv"  delimiter = ';' MISSOVER DSD lrecl=32767 firstobs=2 ;
	input  i:$6. hs6:$6. t:4. uv:best32. qty:best32. v:best32.   j:$6.;
	tyty=length(hs6); 
	if tyty=5 then hs6=cats('0',hs6);
	rename qty=q;
	drop tyty;
run;

data db.imp;
	infile "E:\DATA_CE\trade_price\imptp92_08.csv"  delimiter = ';' MISSOVER DSD lrecl=32767 firstobs=2 ;
	input  i:$6. hs6:$6. t:4. uv:best32. qty:best32. v:best32.   j:$6.;
	tyty=length(hs6); 
	if tyty=5 then hs6=cats('0',hs6);
	rename qty=q;
	drop tyty;
run;

%let label=M  ; *to give a label to the output; 
%let in=db.imp; *created by baci_isic.sas;
%let refyear=1993; * reference year, for Laspeyres and Paasche non chained indices; 
%let baseyear=1995; * base year, price indices=100;
%let source0=pr.baciclean0&refyear&label; *output of outlier program for simple indices ;
%let sourcech=pr.bacicleanch&refyear&label;*output of outlier program for chained indices; 
%let prod=hs6; 
%let sect=hs6 ; *to specify the sector name. To get aggregated index, let sect= ; 
%let i=j; *j for import price indices & i for export price indices;
*only one of the 3 following macro must be used (let a star (*) before the two others); 
*%let condition=first.&i; *to have aggregated index (country level);
%let condition=first.&i or first.&sect; *to have index country*sector;
*%let condition=first.&sect; *to have sectoral index (no country dimension);


/***************************************************************************************/
/***********************    Export & Import Unit Value Indices     *********************/
/**************************************************************************************/
/* L=Laspeyres P=Pasche p=price c=chained F=Fisher Tq=Tornqvist G=Gomtric*/

/*compute Laspeyres, Paasche Fisher and Tornqvist indices*/
%include "&cheminF.\outliers.sas"; /* to deal with outliers */
%include "&cheminF.\l_gl.sas";/* L and gL*/
%include "&cheminF.\cl_cgl.sas";/*cfL and cgL */
%include "&cheminF.\p_gp.sas";/*P and gP*/
%include "&cheminF.\cp_cgp.sas";/*cP cgP*/
%include "&cheminF.\f_cf_t_ct.sas";/*F T cF cT*/

PROC EXPORT DATA=pr.idx19931995ihs6x	OUTFILE="E:\DATA_CE\trade_price\idx1993ihs6exp.csv" DBMS=csv REPLACE;	RUN; 
PROC EXPORT DATA=pr.Idx19931995jhs6m	OUTFILE="E:\DATA_CE\trade_price\idx1993ihs6imp.csv" DBMS=csv REPLACE;	RUN; 
